@@ -4,7 +4,8 @@ sys.path.append(os.path.dirname(os.path.realpath(__file__)))  # enables relative
 
 import dataclasses
 
-import info
+#import info
+from info import platform_info
 
 
 @dataclasses.dataclass
